Class: SiteimproveAPIClient::ApiIgnoredReadabilityPageAutomatedReadability

Inherits:
Object
  • Object
show all
Defined in:
lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApiIgnoredReadabilityPageAutomatedReadability

Initializes the object



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SiteimproveAPIClient::ApiIgnoredReadabilityPageAutomatedReadability` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SiteimproveAPIClient::ApiIgnoredReadabilityPageAutomatedReadability`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'chars_with_digits')
    self.chars_with_digits = attributes[:'chars_with_digits']
  end

  if attributes.key?(:'checking_now')
    self.checking_now = attributes[:'checking_now']
  end

  if attributes.key?(:'cms_url')
    self.cms_url = attributes[:'cms_url']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  end

  if attributes.key?(:'decision_id')
    self.decision_id = attributes[:'decision_id']
  end

  if attributes.key?(:'long_sentences_with_digits_unique')
    self.long_sentences_with_digits_unique = attributes[:'long_sentences_with_digits_unique']
  end

  if attributes.key?(:'long_words_unique')
    self.long_words_unique = attributes[:'long_words_unique']
  end

  if attributes.key?(:'page_level')
    self.page_level = attributes[:'page_level']
  end

  if attributes.key?(:'page_views')
    self.page_views = attributes[:'page_views']
  end

  if attributes.key?(:'sentences_with_digits')
    self.sentences_with_digits = attributes[:'sentences_with_digits']
  end

  if attributes.key?(:'words')
    self.words = attributes[:'words']
  end

  if attributes.key?(:'_siteimprove')
    self._siteimprove = attributes[:'_siteimprove']
  end
end

Instance Attribute Details

#_siteimprove ⇒ Object

Returns the value of attribute _siteimprove.



63
64
65
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 63

def _siteimprove
  @_siteimprove
end

#chars_with_digits ⇒ Object

Number of characters (including digits).



28
29
30
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 28

def chars_with_digits
  @chars_with_digits
end

#checking_now ⇒ Object

Is true if page is being checked now; otherwise false.



31
32
33
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 31

def checking_now
  @checking_now
end

#cms_url ⇒ Object

Url for the cms entry for editing the page.



34
35
36
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 34

def cms_url
  @cms_url
end

#created_by ⇒ Object

The name of the user who created this decision.



37
38
39
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 37

def created_by
  @created_by
end

#created_time ⇒ Object

Timestamp for when the decision for this ignored page was created.



40
41
42
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 40

def created_time
  @created_time
end

#decision_id ⇒ Object

Id of the decision.



43
44
45
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 43

def decision_id
  @decision_id
end

#id ⇒ Object

Id of page.



19
20
21
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 19

def id
  @id
end

#long_sentences_with_digits_unique ⇒ Object

Number of unique long sentences (including digits).



46
47
48
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 46

def long_sentences_with_digits_unique
  @long_sentences_with_digits_unique
end

#long_words_unique ⇒ Object

Number of unique long words.



49
50
51
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 49

def long_words_unique
  @long_words_unique
end

#page_level ⇒ Object

Page level in site hierarchy.



52
53
54
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 52

def page_level
  @page_level
end

#page_views ⇒ Object

Number of times this page has been viewed



55
56
57
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 55

def page_views
  @page_views
end

#sentences_with_digits ⇒ Object

Number of sentences (including digits).



58
59
60
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 58

def sentences_with_digits
  @sentences_with_digits
end

#title ⇒ Object

Title of the page



22
23
24
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 22

def title
  @title
end

#url ⇒ Object

URL for the live version of the page.



25
26
27
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 25

def url
  @url
end

#words ⇒ Object

Number of words.



61
62
63
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 61

def words
  @words
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 88

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 66

def self.attribute_map
  {
    :'id' => :'id',
    :'title' => :'title',
    :'url' => :'url',
    :'chars_with_digits' => :'chars_with_digits',
    :'checking_now' => :'checking_now',
    :'cms_url' => :'cms_url',
    :'created_by' => :'created_by',
    :'created_time' => :'created_time',
    :'decision_id' => :'decision_id',
    :'long_sentences_with_digits_unique' => :'long_sentences_with_digits_unique',
    :'long_words_unique' => :'long_words_unique',
    :'page_level' => :'page_level',
    :'page_views' => :'page_views',
    :'sentences_with_digits' => :'sentences_with_digits',
    :'words' => :'words',
    :'_siteimprove' => :'_siteimprove'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



296
297
298
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 296

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



115
116
117
118
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 93

def self.openapi_types
  {
    :'id' => :'Integer',
    :'title' => :'String',
    :'url' => :'String',
    :'chars_with_digits' => :'Integer',
    :'checking_now' => :'Boolean',
    :'cms_url' => :'String',
    :'created_by' => :'String',
    :'created_time' => :'Time',
    :'decision_id' => :'Integer',
    :'long_sentences_with_digits_unique' => :'Integer',
    :'long_words_unique' => :'Integer',
    :'page_level' => :'Integer',
    :'page_views' => :'Integer',
    :'sentences_with_digits' => :'Integer',
    :'words' => :'Integer',
    :'_siteimprove' => :'Siteimprove2'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 260

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      title == o.title &&
      url == o.url &&
      chars_with_digits == o.chars_with_digits &&
      checking_now == o.checking_now &&
      cms_url == o.cms_url &&
      created_by == o.created_by &&
      created_time == o.created_time &&
      decision_id == o.decision_id &&
      long_sentences_with_digits_unique == o.long_sentences_with_digits_unique &&
      long_words_unique == o.long_words_unique &&
      page_level == o.page_level &&
      page_views == o.page_views &&
      sentences_with_digits == o.sentences_with_digits &&
      words == o.words &&
      _siteimprove == o._siteimprove
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 327

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = SiteimproveAPIClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 398

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 303

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


283
284
285
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 283

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



289
290
291
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 289

def hash
  [id, title, url, chars_with_digits, checking_now, cms_url, created_by, created_time, decision_id, long_sentences_with_digits_unique, long_words_unique, page_level, page_views, sentences_with_digits, words, _siteimprove].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 202

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @chars_with_digits.nil?
    invalid_properties.push('invalid value for "chars_with_digits", chars_with_digits cannot be nil.')
  end

  if @checking_now.nil?
    invalid_properties.push('invalid value for "checking_now", checking_now cannot be nil.')
  end

  if @created_time.nil?
    invalid_properties.push('invalid value for "created_time", created_time cannot be nil.')
  end

  if @decision_id.nil?
    invalid_properties.push('invalid value for "decision_id", decision_id cannot be nil.')
  end

  if @long_sentences_with_digits_unique.nil?
    invalid_properties.push('invalid value for "long_sentences_with_digits_unique", long_sentences_with_digits_unique cannot be nil.')
  end

  if @long_words_unique.nil?
    invalid_properties.push('invalid value for "long_words_unique", long_words_unique cannot be nil.')
  end

  if @sentences_with_digits.nil?
    invalid_properties.push('invalid value for "sentences_with_digits", sentences_with_digits cannot be nil.')
  end

  if @words.nil?
    invalid_properties.push('invalid value for "words", words cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)



374
375
376
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 374

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 380

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object



368
369
370
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 368

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/siteimprove_api_client/models/api_ignored_readability_page_automated_readability.rb', line 245

def valid?
  return false if @id.nil?
  return false if @chars_with_digits.nil?
  return false if @checking_now.nil?
  return false if @created_time.nil?
  return false if @decision_id.nil?
  return false if @long_sentences_with_digits_unique.nil?
  return false if @long_words_unique.nil?
  return false if @sentences_with_digits.nil?
  return false if @words.nil?
  true
end