Class: SiteimproveAPIClient::IgnoredIssues

Inherits:
Object
  • Object
show all
Defined in:
lib/siteimprove_api_client/models/ignored_issues.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IgnoredIssues

Initializes the object



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SiteimproveAPIClient::IgnoredIssues` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SiteimproveAPIClient::IgnoredIssues`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'ignored_by')
    self.ignored_by = attributes[:'ignored_by']
  end

  if attributes.key?(:'ignored_time')
    self.ignored_time = attributes[:'ignored_time']
  end

  if attributes.key?(:'issue_type')
    self.issue_type = attributes[:'issue_type']
  else
    self.issue_type = 'duplicate_page_title'
  end

  if attributes.key?(:'issues')
    self.issues = attributes[:'issues']
  end

  if attributes.key?(:'note')
    self.note = attributes[:'note']
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  else
    self.severity = 'review'
  end

  if attributes.key?(:'_links')
    self._links = attributes[:'_links']
  end
end

Instance Attribute Details

Returns the value of attribute _links.



39
40
41
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 39

def _links
  @_links
end

#id ⇒ Object

Id of note (if present).



19
20
21
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 19

def id
  @id
end

#ignored_by ⇒ Object

The name of the user who ignored this SEO issue.



22
23
24
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 22

def ignored_by
  @ignored_by
end

#ignored_time ⇒ Object

The time when this SEO issue was ignored.



25
26
27
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 25

def ignored_time
  @ignored_time
end

#issue_type ⇒ Object

The type of this issue.



28
29
30
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 28

def issue_type
  @issue_type
end

#issues ⇒ Object

The number of SEO issues of this type that was ignored.



31
32
33
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 31

def issues
  @issues
end

#note ⇒ Object

Optional note which the user can fill out with a description of why this SEO issue was ignored.



34
35
36
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 34

def note
  @note
end

#severity ⇒ Object

Issue severity: error, warning, review.



37
38
39
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 37

def severity
  @severity
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 64

def self.attribute_map
  {
    :'id' => :'id',
    :'ignored_by' => :'ignored_by',
    :'ignored_time' => :'ignored_time',
    :'issue_type' => :'issue_type',
    :'issues' => :'issues',
    :'note' => :'note',
    :'severity' => :'severity',
    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



236
237
238
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 236

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



97
98
99
100
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 83

def self.openapi_types
  {
    :'id' => :'Integer',
    :'ignored_by' => :'String',
    :'ignored_time' => :'Time',
    :'issue_type' => :'String',
    :'issues' => :'Integer',
    :'note' => :'String',
    :'severity' => :'String',
    :'_links' => :'Links3'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 208

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      ignored_by == o.ignored_by &&
      ignored_time == o.ignored_time &&
      issue_type == o.issue_type &&
      issues == o.issues &&
      note == o.note &&
      severity == o.severity &&
      _links == o._links
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 267

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = SiteimproveAPIClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 338

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 243

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


223
224
225
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 223

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



229
230
231
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 229

def hash
  [id, ignored_by, ignored_time, issue_type, issues, note, severity, _links].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 156

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @issue_type.nil?
    invalid_properties.push('invalid value for "issue_type", issue_type cannot be nil.')
  end

  if @severity.nil?
    invalid_properties.push('invalid value for "severity", severity cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)



314
315
316
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 314

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 320

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object



308
309
310
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 308

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



175
176
177
178
179
180
181
182
183
184
# File 'lib/siteimprove_api_client/models/ignored_issues.rb', line 175

def valid?
  return false if @id.nil?
  return false if @issue_type.nil?
  issue_type_validator = EnumAttributeValidator.new('String', ["duplicate_page_title", "duplicate_meta_descriptions", "duplicate_h1_headings", "pages_without_meta_description", "pages_without_h1_heading", "pages_without_page_title", "page_not_included_in_xml_sitemap", "page_excluded_by_robots", "page_excluded_by_rel_canonical", "page_excluded_by_noindex_nofollow", "keyword_not_included_in_meta_description", "keyword_not_included_in_image_alt_text", "keyword_not_included_in_sub_headings", "keyword_not_included_in_page_title", "keyword_not_included_in_url", "keyword_not_included_in_h1_heading", "keyword_not_included_in_internal_link_text", "redirect"])
  return false unless issue_type_validator.valid?(@issue_type)
  return false if @severity.nil?
  severity_validator = EnumAttributeValidator.new('String', ["review", "warning", "error"])
  return false unless severity_validator.valid?(@severity)
  true
end